@@ -310,7 +310,7 @@ class ISSocket
     @mutex.synchronize do
       begin
         @@logger.debug( "writeData::data: -#{data}-")
-        @socket.puts( data)
+        @socket.puts( data + '\r')
         @socket.flush
       rescue Exception => ex
         @@logger.warn( "ex: " + ex)
