@@ -35,10 +35,11 @@ class KISSDevice
   @@logger = Logger.get_logger( "KISSDevice")
   
 
-  def initialize( device, call, speed, timeout, mode)
-    @@logger.info( "initialize( device, call, speed, timeout, mode)")
+  def initialize( device, baudrate, call, speed, timeout, mode)
+    @@logger.info( "initialize( device, baudrate, call, speed, timeout, mode)")
     
     @device = device
+    @baudrate = baudrate 
     @call = call
     @speed = speed
     @timeout = timeout
@@ -61,7 +62,13 @@ class KISSDevice
         @port.close
       end
       
-      @port = SerialPort.new( @device, 9600, 8, 1, SerialPort::NONE)
+      # default baud rate
+      baudrate = 9600 
+      if @baudrate
+        baudrate = @baudrate
+      end
+
+      @port = SerialPort.new( @device, baudrate, 8, 1, SerialPort::NONE)
       @port.nonblock = true 
       @port.sync = true
       
