@@ -22,11 +22,11 @@ require 'aprs4r/PluginConfiguration'
 
 class LCD4LinuxPluginConfiguration < PluginConfiguration
 
-  attr_reader :file
-  attr_writer :file
+  attr_reader :file, :devices
+  attr_writer :file, :devices
 
   def to_yaml_properties
-    %w{ super @file}
+    %w{ super @file @devices}
   end
 
 end
