@@ -22,6 +22,8 @@ require 'Logger'
 require 'aprs4r/LCD4LinuxPlugin'
 require 'aprs4r/MessagePlugin'
 require 'aprs4r/QueryPlugin'
+require 'aprs4r/WeatherPlugin'
+require 'aprs4r/WMRWeatherPlugin'
 require 'aprs4r/XMLDataPlugin'
 require 'aprs4r/ISServerPlugin'
 
@@ -51,6 +53,8 @@ class PluginManager
     
     @@configuration.each { |name, configuration| 
 
+      @@logger.debug( "configuration: #{configuration}")
+
       name = configuration.name
       type = configuration.type
       enable = configuration.enable
@@ -72,6 +76,8 @@ class PluginManager
           plugin = MessagePlugin.new( configuration)
         elsif type == "QueryPlugin"
           plugin = QueryPlugin.new( configuration)
+        elsif type == "WMRWeatherPlugin"
+          plugin = WMRWeatherPlugin.new( configuration)
         elsif type == "ISServerPlugin"
           plugin = ISServerPlugin.new( configuration)
         end
