@@ -45,12 +45,6 @@ class SocketManager
   def SocketManager.init( configuration)
     @@logger.info( "init( configuration)")
 
-    # dirty hack
-    @@recvCount["rf0"] = 0 
-    @@sendCount["rf0"] = 0
-    @@recvCount["is0"] = 0 
-    @@sendCount["is0"] = 0 
-
     sockets = configuration.devices
 
     if sockets.nil?
@@ -67,9 +61,9 @@ class SocketManager
         socket = nil
 
         # FIXME: dynamic class loading
-        if name == "is0"
+        if name =~ /^is\d$/
           socket = ISSocket.new( configuration)
-        elsif name == "rf0"
+        elsif name =~ /^rf\d$/
           socket = AX25Socket.new( configuration)
         end
         
@@ -230,22 +224,14 @@ class SocketManager
   end
 
   
-  def SocketManager.recvCount( name)
+  def SocketManager.recv_count( name)
     return @@recvCount[name]
   end
 
-  def SocketManager.setrecvCount( name, count)
-    @@recvCount[name] = count
-  end
-  
-  def SocketManager.sendCount( name)
+  def SocketManager.send_count( name)
     return @@sendCount[name]
   end
 
-  def SocketManager.setsendCount( name, count)
-    @@sendCount[name] = count
-  end
-
   def SocketManager.lastMessage
     return @@lastMessage
   end
